@@ -22,10 +22,12 @@ HTML = """
 class S3DirectEditor(widgets.TextInput):
 
     class Media:
-        js = {
-            's3direct/js/require.js',
+        js = (
+            'ajaximage/js/jquery.iframe-transport.js',
+            'ajaximage/js/jquery.ui.widget.js',
+            'ajaximage/js/jquery.fileupload.js',
             's3direct/js/s3direct.js',
-        }
+        )
         css = {
             'all': (
                 's3direct/css/bootstrap-progress.min.css',
